import React, { Suspense, lazy } from "react";
import { Switch, Route } from "react-router-dom";

import * as routes from './constants/routes'

import Header from "./containers/Header"
import landingPage from './components/landingPage'
import Footer from './components/footer'
import PrivateRouter from './PrivateRouter'

import Spinner from "./components/common/spinner";

const notFound   = lazy(() => import("./components/notFound"));
const homePage   = lazy(() => import("./components/homePage"));
const signInPage = lazy(() => import("./containers/auth/SignInPage"));
const signUpPage = lazy(() => import("./containers/auth/SignUpPage"));
const createTestPage = lazy(() => import("./components/admin-components/createTestPage"));

export default () => (
    <div className="app">
        <Header />
        <Suspense fallback={<Spinner />}>
            <Switch>
                <Route path={routes.LANDING} exact component={landingPage} />
                <Route path={routes.SIGN_IN} exact component={signInPage} />
                <Route path={routes.SIGN_UP} exact component={signUpPage} />

                <PrivateRouter path={routes.HOME} user={false} component={homePage}/>
                <PrivateRouter path={routes.TESTS} user={false} component={null}/>
                <PrivateRouter path={routes.CATEGORIES} user={false} component={null}/>
                <PrivateRouter path={routes.PROFILE} user={false} component={null} />

                <PrivateRouter path={routes.CREATE_TEST} user={true} component={createTestPage} />
                <PrivateRouter path={routes.CREATE_CATEGORY} user={false} component={createTestPage} />
                <PrivateRouter path={routes.DELETE_USER} user={false} component={createTestPage} />
                
                <Route component={notFound} />
            </Switch>
        </Suspense>
        <Footer />
    </div>
);
